from django.contrib.auth.decorators import login_required
from django.db.models import Q
from django.shortcuts import render

from inventory.models import RacksUser, InventoryObject, Lab


def get_racks_user(request):
    try:
        return RacksUser.objects.get(username=request.user.username)
    except RacksUser.DoesNotExist:
        return None


@login_required
def assigned(request):
    racks_user = get_racks_user(request)

    context = {
        'racks_user': racks_user,
        'assigned_objects': InventoryObject.objects.filter(Q(assigned_user=racks_user) |
                                                           Q(assigned_group__users=racks_user)),
        'assigned_labs': Lab.objects.filter(Q(assigned_user=racks_user) |
                                            Q(assigned_group__users=racks_user)),
    }

    return render(request, 'account/assigned.html', context)


@login_required
def responsible(request):
    racks_user = get_racks_user(request)

    context = {
        'racks_user': racks_user,
        'inventory_objects': racks_user.inventory_objects.all() if racks_user else None,
        'labs': racks_user.labs.all() if racks_user else None,
    }

    return render(request, 'account/responsible.html', context)
