from __future__ import absolute_import

import logging
from functools import wraps

from celery import shared_task, chain
from django.conf import settings

import dcim.importer
import importers.ldap
import importers.switches
import importers.zabbix
import importers.puppet


log = logging.getLogger('importers.tasks')


def racks_task(func):
    task_name = func.__name__
    time_limit = settings.TASK_TIME_LIMITS[task_name]

    @shared_task(time_limit=time_limit, ignore_result=True)
    @wraps(func)
    def wrapper(*args, **kwargs):
        log.info("Starting task %s...", task_name)
        try:
            func(*args, **kwargs)
        except Exception, e:
            log.exception("Task %s failed: %s.", task_name, e)
        else:
            log.info("Task %s done.", task_name)

    return wrapper


@racks_task
def import_zabbix_hosts():
    importers.zabbix.import_hosts()


@racks_task
def import_puppet_attributes():
    importers.puppet.import_puppet_attributes()


@racks_task
def import_dcim_servers():
    dcim.importer.import_servers()


@racks_task
def import_dcim_switches():
    dcim.importer.import_switches()


@racks_task
def import_switches_address_tables():
    importers.switches.import_address_tables()


@racks_task
def bind_dcim_to_switch_ports():
    importers.switches.bind_dcim_to_switch_ports()


@racks_task
def bind_dcim_servers_to_inventory():
    importers.switches.bind_dcim_servers_to_inventory()


@racks_task
def import_users_from_ldap():
    importers.ldap.import_users()


import_all = chain(
    import_zabbix_hosts.si(),
    import_puppet_attributes.si(),

    import_dcim_servers.si(),
    import_dcim_switches.si(),
    import_switches_address_tables.si(),
    bind_dcim_to_switch_ports.si(),
    bind_dcim_servers_to_inventory.si(),
    import_users_from_ldap.si(),
)
