from rest_framework import serializers

from inventory.models import (
    FacterLocation,
    InventoryObject,
    InventoryObjectAttribute,
    InventoryObjectLabel,
    InventoryObjectType,
    IPv4Network,
    RacksUser,
)


class FacterLocationSerializer(serializers.ModelSerializer):
    class Meta:
        model = FacterLocation
        fields = ('fact',)


class InventoryObjectTypeSerializer(serializers.ModelSerializer):
    class Meta:
        model = InventoryObjectType
        fields = ('name',)


class UserSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = RacksUser
        fields = ('id', 'url', 'username', 'email', 'groups',)


class IPv4NetworkSerializer(serializers.ModelSerializer):
    class Meta:
        model = IPv4Network
        fields = ('id', 'address', 'netmask', 'gateway',)


class InventoryObjectLabelSerializer(serializers.ModelSerializer):
    class Meta:
        model = InventoryObjectLabel


class InventoryObjectAttributeSerializer(serializers.ModelSerializer):
    class Meta:
        model = InventoryObjectAttribute
        fields = ('id', 'object', 'name', 'value')


class InventoryObjectSerializer(serializers.ModelSerializer):
    labels = serializers.SerializerMethodField('labels_list')
    location = serializers.SerializerMethodField('get_location')
    facter_location = FacterLocationSerializer(many=False, required=False)
    type = InventoryObjectTypeSerializer(many=False, required=False)
    attributes = serializers.SerializerMethodField('attributes_dict')
    responsible = serializers.SerializerMethodField('responsible_list')

    class Meta:
        model = InventoryObject
        fields = (
            'id',
            'name',
            'location',
            'facter_location',
            'type',
            'labels',
            'attributes',
            'responsible',)

    def get_location(self, obj):
        if obj.facter_location and obj.facter_location.location:
            return {
                'name': obj.facter_location.location.name
            }

        return None

    def attributes_dict(self, obj):
        attrs = {}
        for attr in obj.attributes.all():
            attrs[attr.name] = attr.value

        return attrs

    def labels_list(self, obj):
        return [x.name for x in obj.label.all()]

    def responsible_list(self, obj):
        return [x.username for x in obj.responsible.all()]
