ALLOW_NONE, ALLOW_VIEW, ALLOW_EDIT = range(3)


class EditAll(object):
    def __init__(self, create=False, delete=False):
        self.create = create
        self.delete = delete

    def get_field_permissions(self, field_name):
        return ALLOW_EDIT


class ViewAll(object):
    create = delete = False

    def get_field_permissions(self, field_name):
        return ALLOW_VIEW


VIEW_ALL = ViewAll()


class Permissions(object):
    def __init__(self, create=False, delete=False, edit=(), view=()):
        self.create = create
        self.delete = delete
        self.edit = edit
        self.view = view

    def get_field_permissions(self, field_name):
        if field_name in self.edit:
            return ALLOW_EDIT
        if field_name in self.view:
            return ALLOW_VIEW
        return ALLOW_NONE


class ViewOnly(Permissions):
    def __init__(self, *fields):
        self.create = self.delete = False
        self.fields = fields

        super(ViewOnly, self).__init__(create=False, delete=False, edit=(), view=fields)


class ValueWithoutAccess(object):
    no_access = True

    def __init__(self, value):
        self._value = value

    def __nonzero__(self):
        return bool(self._value)

    # Attributes have no access too
    def __getattr__(self, name):
        return self

    # Result of calls have no access either
    def __call__(self, *args, **kwargs):
        return self

    def __iter__(self):
        return iter([self])

    def __len__(self):
        return 1


class ProtectedObject(object):
    def __init__(self, obj, permissions):
        self.object = obj
        self.permissions = permissions

    def __getattr__(self, name):
        value = getattr(self.object, name)

        # Special case for links, should be always accessible
        if name == 'pk':
            return value

        # Special case for None, considered safe value
        if value is None:
            return None

        # Special case for blank, considered safe value
        if value == '':
            return ''

        field_permissions = self.permissions.get_field_permissions(name)

        if field_permissions in (ALLOW_EDIT, ALLOW_VIEW):
            return value

        return ValueWithoutAccess(value)


def can_view(*values):
    for value in values:
        if isinstance(value, ValueWithoutAccess):
            return False

    return True
