from django.conf.urls import include, patterns, url
from rest_framework import routers

from inventory import api

router = routers.DefaultRouter()
router.register(r'users', api.UserViewSet)
router.register(r'objects', api.InventoryObjectViewSet)
router.register(r'ipv4networks', api.IPv4NetworkViewSet)
router.register(r'attributes', api.InventoryObjectAttributeViewSet)
router.register(r'labels', api.InventoryObjectLabelViewSet)

urlpatterns = patterns(
    '',
    (r'^api\/v1\/import\.json$', 'inventory.views.api_import'),
    (r'^api\/v1\/lookup\.json$', 'inventory.views.api_lookup'),
    (r'^api\/v1\/object\/list\.json$', 'inventory.views.api_object_list'),
    (r'^api\/v1\/object\/list\/inventory\.json$',
        'inventory.views.api_object_list_inventory'),
    (r'^api/v1\/search/suggest.json', 'inventory.views.api_suggest'),

    # API v2 views
    (r'^api\/v2\/', include(router.urls)),

    # Old urls
    url(r'^account\/applications/(?P<applicationid>[0-9]+)\.html', 'security.views.application',
        name='security.applications.view'),
    url(r'^account\/applications\.html$', 'security.views.applications',
        name='security.applications.list'),
    (r'^account\/profile\.html$', 'security.views.profile'),
    (r'^export\/object\/inventory\.csv',
        'inventory.views.export_object_inventory'),
    (r'^labels\.html$', 'inventory.views.labels'),
    (r'^reports\/basic\.html$', 'reports.views.basic'),
    url(r'^search\.html$', 'inventory.views.search', name='inventory.objects.search'),
    (r'^account\/login\.html$', 'security.views.login_view'),
    (r'^account\/logout\.html$', 'security.views.logout_view'),

    url(r'^launchpad/authorize$', 'launchpad.views.authorize', name='launchpad.authorize'),
    url(r'^launchpad/fetchbugs$', 'launchpad.views.fetch_bugs_json'),

    url(r'^account/assigned', 'account.views.assigned', name='account.assigned'),
    url(r'^account/responsible$', 'account.views.responsible', name='account.responsible'),

    # Objects
    url(r'^', include('inventory.views.objects')),
    url(r'^labs/', include('inventory.views.labs')),
    url(r'^vlans/', include('inventory.views.vlans')),
    url(r'^locations/', include('inventory.views.locations')),
    url(r'^ipv4networks/', include('inventory.views.ipv4networks')),
)
